Class: ESI::UserInterfaceApi

Inherits:
Object
  • Object
show all
Defined in:
lib/esi-client-bvv/api/user_interface_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UserInterfaceApi

Returns a new instance of UserInterfaceApi.



19
20
21
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#post_ui_autopilot_waypoint(add_to_beginning, clear_other_waypoints, destination_id, opts = {}) ⇒ nil

Set Autopilot Waypoint Set a solar system as autopilot waypoint —

Parameters:

  • add_to_beginning

    Whether this solar system should be added to the beginning of all waypoints

  • clear_other_waypoints

    Whether clean other waypoints beforing adding this one

  • destination_id

    The destination to travel to, can be solar system, station or structure's id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from (default to tranquility)

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (nil)


34
35
36
37
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 34

def post_ui_autopilot_waypoint(add_to_beginning, clear_other_waypoints, destination_id, opts = {})
  post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, opts)
  return nil
end

#post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Set Autopilot Waypoint Set a solar system as autopilot waypoint —

Parameters:

  • add_to_beginning

    Whether this solar system should be added to the beginning of all waypoints

  • clear_other_waypoints

    Whether clean other waypoints beforing adding this one

  • destination_id

    The destination to travel to, can be solar system, station or structure&#39;s id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (Array<(nil, Fixnum, Hash)>)

    nil, response status code and response headers



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 50

def post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UserInterfaceApi.post_ui_autopilot_waypoint ..."
  end
  # verify the required parameter 'add_to_beginning' is set
  if @api_client.config.client_side_validation && add_to_beginning.nil?
    fail ArgumentError, "Missing the required parameter 'add_to_beginning' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify the required parameter 'clear_other_waypoints' is set
  if @api_client.config.client_side_validation && clear_other_waypoints.nil?
    fail ArgumentError, "Missing the required parameter 'clear_other_waypoints' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify the required parameter 'destination_id' is set
  if @api_client.config.client_side_validation && destination_id.nil?
    fail ArgumentError, "Missing the required parameter 'destination_id' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  if @api_client.config.client_side_validation && opts[:'datasource'] && !['tranquility', 'singularity'].include?(opts[:'datasource'])
    fail ArgumentError, 'invalid value for "datasource", must be one of tranquility, singularity'
  end
  # resource path
  local_var_path = "/v2/ui/autopilot/waypoint/"

  # query parameters
  query_params = {}
  query_params[:'add_to_beginning'] = add_to_beginning
  query_params[:'clear_other_waypoints'] = clear_other_waypoints
  query_params[:'destination_id'] = destination_id
  query_params[:'datasource'] = opts[:'datasource'] if !opts[:'datasource'].nil?
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?
  query_params[:'user_agent'] = opts[:'user_agent'] if !opts[:'user_agent'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-User-Agent'] = opts[:'x_user_agent'] if !opts[:'x_user_agent'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['evesso']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_autopilot_waypoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_contract(contract_id, opts = {}) ⇒ nil

Open Contract Window Open the contract window inside the client —

Parameters:

  • contract_id

    The contract to open

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from (default to tranquility)

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (nil)


116
117
118
119
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 116

def post_ui_openwindow_contract(contract_id, opts = {})
  post_ui_openwindow_contract_with_http_info(contract_id, opts)
  return nil
end

#post_ui_openwindow_contract_with_http_info(contract_id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Open Contract Window Open the contract window inside the client —

Parameters:

  • contract_id

    The contract to open

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (Array<(nil, Fixnum, Hash)>)

    nil, response status code and response headers



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 130

def post_ui_openwindow_contract_with_http_info(contract_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UserInterfaceApi.post_ui_openwindow_contract ..."
  end
  # verify the required parameter 'contract_id' is set
  if @api_client.config.client_side_validation && contract_id.nil?
    fail ArgumentError, "Missing the required parameter 'contract_id' when calling UserInterfaceApi.post_ui_openwindow_contract"
  end
  if @api_client.config.client_side_validation && opts[:'datasource'] && !['tranquility', 'singularity'].include?(opts[:'datasource'])
    fail ArgumentError, 'invalid value for "datasource", must be one of tranquility, singularity'
  end
  # resource path
  local_var_path = "/v1/ui/openwindow/contract/"

  # query parameters
  query_params = {}
  query_params[:'contract_id'] = contract_id
  query_params[:'datasource'] = opts[:'datasource'] if !opts[:'datasource'].nil?
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?
  query_params[:'user_agent'] = opts[:'user_agent'] if !opts[:'user_agent'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-User-Agent'] = opts[:'x_user_agent'] if !opts[:'x_user_agent'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['evesso']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_contract\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_information(target_id, opts = {}) ⇒ nil

Open Information Window Open the information window for a character, corporation or alliance inside the client —

Parameters:

  • target_id

    The target to open

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from (default to tranquility)

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (nil)


186
187
188
189
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 186

def post_ui_openwindow_information(target_id, opts = {})
  post_ui_openwindow_information_with_http_info(target_id, opts)
  return nil
end

#post_ui_openwindow_information_with_http_info(target_id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Open Information Window Open the information window for a character, corporation or alliance inside the client —

Parameters:

  • target_id

    The target to open

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (Array<(nil, Fixnum, Hash)>)

    nil, response status code and response headers



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 200

def post_ui_openwindow_information_with_http_info(target_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UserInterfaceApi.post_ui_openwindow_information ..."
  end
  # verify the required parameter 'target_id' is set
  if @api_client.config.client_side_validation && target_id.nil?
    fail ArgumentError, "Missing the required parameter 'target_id' when calling UserInterfaceApi.post_ui_openwindow_information"
  end
  if @api_client.config.client_side_validation && opts[:'datasource'] && !['tranquility', 'singularity'].include?(opts[:'datasource'])
    fail ArgumentError, 'invalid value for "datasource", must be one of tranquility, singularity'
  end
  # resource path
  local_var_path = "/v1/ui/openwindow/information/"

  # query parameters
  query_params = {}
  query_params[:'target_id'] = target_id
  query_params[:'datasource'] = opts[:'datasource'] if !opts[:'datasource'].nil?
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?
  query_params[:'user_agent'] = opts[:'user_agent'] if !opts[:'user_agent'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-User-Agent'] = opts[:'x_user_agent'] if !opts[:'x_user_agent'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['evesso']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_information\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_marketdetails(type_id, opts = {}) ⇒ nil

Open Market Details Open the market details window for a specific typeID inside the client —

Parameters:

  • type_id

    The item type to open in market window

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from (default to tranquility)

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (nil)


256
257
258
259
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 256

def post_ui_openwindow_marketdetails(type_id, opts = {})
  post_ui_openwindow_marketdetails_with_http_info(type_id, opts)
  return nil
end

#post_ui_openwindow_marketdetails_with_http_info(type_id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Open Market Details Open the market details window for a specific typeID inside the client —

Parameters:

  • type_id

    The item type to open in market window

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (Array<(nil, Fixnum, Hash)>)

    nil, response status code and response headers



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 270

def post_ui_openwindow_marketdetails_with_http_info(type_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UserInterfaceApi.post_ui_openwindow_marketdetails ..."
  end
  # verify the required parameter 'type_id' is set
  if @api_client.config.client_side_validation && type_id.nil?
    fail ArgumentError, "Missing the required parameter 'type_id' when calling UserInterfaceApi.post_ui_openwindow_marketdetails"
  end
  if @api_client.config.client_side_validation && opts[:'datasource'] && !['tranquility', 'singularity'].include?(opts[:'datasource'])
    fail ArgumentError, 'invalid value for "datasource", must be one of tranquility, singularity'
  end
  # resource path
  local_var_path = "/v1/ui/openwindow/marketdetails/"

  # query parameters
  query_params = {}
  query_params[:'type_id'] = type_id
  query_params[:'datasource'] = opts[:'datasource'] if !opts[:'datasource'].nil?
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?
  query_params[:'user_agent'] = opts[:'user_agent'] if !opts[:'user_agent'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-User-Agent'] = opts[:'x_user_agent'] if !opts[:'x_user_agent'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['evesso']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_marketdetails\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_newmail(new_mail, opts = {}) ⇒ nil

Open New Mail Window Open the New Mail window, according to settings from the request if applicable —

Parameters:

  • new_mail

    The details of mail to create

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from (default to tranquility)

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (nil)


326
327
328
329
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 326

def post_ui_openwindow_newmail(new_mail, opts = {})
  post_ui_openwindow_newmail_with_http_info(new_mail, opts)
  return nil
end

#post_ui_openwindow_newmail_with_http_info(new_mail, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Open New Mail Window Open the New Mail window, according to settings from the request if applicable —

Parameters:

  • new_mail

    The details of mail to create

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :datasource (String)

    The server name you would like data from

  • :token (String)

    Access token to use if unable to set a header

  • :user_agent (String)

    Client identifier, takes precedence over headers

  • :x_user_agent (String)

    Client identifier, takes precedence over User-Agent

Returns:

  • (Array<(nil, Fixnum, Hash)>)

    nil, response status code and response headers



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 340

def post_ui_openwindow_newmail_with_http_info(new_mail, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UserInterfaceApi.post_ui_openwindow_newmail ..."
  end
  # verify the required parameter 'new_mail' is set
  if @api_client.config.client_side_validation && new_mail.nil?
    fail ArgumentError, "Missing the required parameter 'new_mail' when calling UserInterfaceApi.post_ui_openwindow_newmail"
  end
  if @api_client.config.client_side_validation && opts[:'datasource'] && !['tranquility', 'singularity'].include?(opts[:'datasource'])
    fail ArgumentError, 'invalid value for "datasource", must be one of tranquility, singularity'
  end
  # resource path
  local_var_path = "/v1/ui/openwindow/newmail/"

  # query parameters
  query_params = {}
  query_params[:'datasource'] = opts[:'datasource'] if !opts[:'datasource'].nil?
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?
  query_params[:'user_agent'] = opts[:'user_agent'] if !opts[:'user_agent'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-User-Agent'] = opts[:'x_user_agent'] if !opts[:'x_user_agent'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(new_mail)
  auth_names = ['evesso']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_newmail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end