Method: ESI::UserInterfaceApi#post_ui_openwindow_information
- Defined in:
- lib/esi-client-bvv/api/user_interface_api.rb
#post_ui_openwindow_information(target_id, opts = {}) ⇒ nil
Open Information Window Open the information window for a character, corporation or alliance inside the client —
172 173 174 175 |
# File 'lib/esi-client-bvv/api/user_interface_api.rb', line 172 def post_ui_openwindow_information(target_id, opts = {}) post_ui_openwindow_information_with_http_info(target_id, opts) return nil end |